@@ -6,6 +6,7 @@ and utilities for defining data models and SQL queries.
 """
 from clickhouse_connect.driver.client import Client as ClickhouseClient
 from clickhouse_connect import get_client
+from moose_lib.dmv2 import OlapTable
 from pydantic import BaseModel
 from dataclasses import dataclass, asdict
 from enum import Enum
@@ -18,7 +19,11 @@ import asyncio
 from string import Formatter
 from temporalio.client import Client as TemporalClient, TLSConfig
 from temporalio.common import RetryPolicy, WorkflowIDConflictPolicy, WorkflowIDReusePolicy
-from datetime import timedelta
+from datetime import timedelta, datetime
+from time import perf_counter
+from humanfriendly import format_timespan
+
+from .data_models import Column
 from .config.runtime import RuntimeClickHouseConfig
 
 from moose_lib.commons import EnhancedJSONEncoder
@@ -181,7 +186,8 @@ class QueryClient:
 
     def execute(self, input, variables, row_type: Type[BaseModel] = None):
         params = {}
-        values = {}
+        values: dict[str, Any] = {}
+        preview_params = {}
 
         for i, (_, variable_name, _, _) in enumerate(Formatter().parse(input)):
             if variable_name:
@@ -190,26 +196,105 @@ class QueryClient:
                     # handling passing the value of the query string dict directly to variables
                     value = value[0]
 
-                t = 'String' if isinstance(value, str) else \
-                    'Int64' if isinstance(value, int) else \
-                        'Float64' if isinstance(value, float) else "String"  # unknown type
+                if isinstance(value, Column) or isinstance(value, OlapTable):
+                    params[variable_name] = f'{{p{i}: Identifier}}'
+                    values[f'p{i}'] = value.name
+                else:
+                    if isinstance(value, bool):
+                        params[variable_name] = f'{{p{i}: Bool}}'
+                        values[f'p{i}'] = value
+                    elif isinstance(value, datetime):
+                        params[variable_name] = f'{{p{i}: DateTime}}'
+                        values[f'p{i}'] = value
+                    elif isinstance(value, int):
+                        params[variable_name] = f'{{p{i}: Int64}}'
+                        values[f'p{i}'] = value
+                    elif isinstance(value, float):
+                        params[variable_name] = f'{{p{i}: Float64}}'
+                        values[f'p{i}'] = value
+                    elif isinstance(value, str):
+                        params[variable_name] = f'{{p{i}: String}}'
+                        values[f'p{i}'] = value
+                    else:
+                        print(f"unhandled type in QueryClient {type(value)}", file=sys.stderr)
+                        params[variable_name] = f'{{p{i}: String}}'
+                        values[f'p{i}'] = str(value)
+                preview_params[variable_name] = self._format_value_for_preview(value)
 
-                params[variable_name] = f'{{p{i}: {t}}}'
-                values[f'p{i}'] = value
         clickhouse_query = input.format_map(params)
+        preview_query = input.format_map(preview_params)
+        print(f"[QueryClient] | Query: {' '.join(preview_query.split())}")
+        return self.execute_raw(
+            clickhouse_query, values, row_type
+        )
 
+    def execute_raw(
+            self,
+            clickhouse_query: str,
+            parameters: Optional[dict[str, Any]],
+            row_type: Type[BaseModel] = None
+    ):
+        """
+        Uses raw clickhouse SQL syntax.
+        """
         # We are not using the result of the ping
         # but this ensures that if the clickhouse cloud service is idle, we
         # wake it up, before we send the query.
         self.ch_client.ping()
 
-        val = self.ch_client.query(clickhouse_query, values)
+        start = perf_counter()
+        val = self.ch_client.query(clickhouse_query, parameters)
+        secs = perf_counter() - start
+        if secs < 1:
+            print(f"[QueryClient] | Query completed: {secs * 1000:.0f} ms")
+        else:
+            print(f"[QueryClient] | Query completed: {format_timespan(secs)}")
 
         if row_type is None:
             return list(val.named_results())
         else:
             return list(row_type(**row) for row in val.named_results())
 
+    def _format_value_for_preview(self, value: Any) -> str:
+        """Format a Python value as a ClickHouse SQL literal for preview logging.
+
+        This does not affect execution; it's only for human-readable query logs.
+        """
+        # NULL handling
+        if value is None:
+            return 'NULL'
+
+        # Booleans (ClickHouse accepts true/false)
+        if isinstance(value, bool):
+            return 'true' if value else 'false'
+
+        # Numbers
+        if isinstance(value, (int, float)) and not isinstance(value, bool):
+            return str(value)
+
+        # Strings
+        if isinstance(value, str):
+            # Escape backslashes and single quotes for ClickHouse single-quoted strings
+            escaped = value.replace('\\', '\\\\').replace("'", "\\'")
+            return f"'{escaped}'"
+
+        # DateTime
+        if isinstance(value, datetime):
+            return f"'{value.strftime('%Y-%m-%d %H:%M:%S')}'"
+
+        if isinstance(value, Column) or isinstance(value, OlapTable):
+            return value.name
+
+        # Lists / tuples (format as [item1, item2, ...])
+        if isinstance(value, (list, tuple)):
+            formatted_items = ', '.join(self._format_value_for_preview(v) for v in value)
+            return f"[{formatted_items}]"
+
+        # Fallback: stringify and single-quote
+        fallback = str(value)
+        escaped_fallback = fallback.replace('\\', '\\\\').replace("'", "\\'")
+        return f"'{escaped_fallback}'"
+
     def close(self):
         """Close the ClickHouse client connection."""
         if self.ch_client:
@@ -308,7 +393,7 @@ class WorkflowClient:
         dmv2_workflow = get_workflow(name)
         if dmv2_workflow is None:
             raise ValueError(f"DMv2 workflow '{name}' not found")
-            
+
         return {
             'retry_count': dmv2_workflow.config.retries or 3,
             'timeout_str': dmv2_workflow.config.timeout or "1h",
@@ -342,8 +427,6 @@ class WorkflowClient:
         """Build workflow arguments for DMv2 workflow."""
         return [{"workflow_name": name, "execution_mode": "start"}, input_data]
 
-
-
     def parse_timeout_to_timedelta(self, timeout_str: str) -> Optional[timedelta]:
         if timeout_str == "never":
             return None  # Unlimited execution timeout
