@@ -328,6 +328,8 @@ def create_producer() -> Optional[KafkaProducer]:
     Returns:
         Configured KafkaProducer instance
     """
+    max_request_size = KafkaProducer.DEFAULT_CONFIG['max_request_size'] if target_topic is None \
+        else target_topic.max_message_bytes
     if sasl_config['mechanism'] is not None:
         return KafkaProducer(
             bootstrap_servers=broker,
@@ -335,13 +337,13 @@ def create_producer() -> Optional[KafkaProducer]:
             sasl_plain_password=sasl_config['password'],
             sasl_mechanism=sasl_config['mechanism'],
             security_protocol=args.security_protocol,
-            max_request_size=target_topic.max_message_bytes
+            max_request_size=max_request_size
         )
     log("No sasl mechanism specified. Using default producer.")
     return KafkaProducer(
         bootstrap_servers=broker,
         max_in_flight_requests_per_connection=1,
-        max_request_size=target_topic.max_message_bytes
+        max_request_size=max_request_size
     )
 
 
